@@ -363,19 +363,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM EXIT_STATE_TRANS_PROFILE;
-DROP VIEW SCI_EXTENTS;
-CREATE VIEW SCI_EXTENTS AS
-SELECT 
-    ID 
-    , O_ID                           AS O_ID
-    , SME_ID                         AS SME_ID
-    , SEQUENCE                       AS SEQUENCE
-    , EXTENT                         AS EXTENT
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-  FROM EXTENTS;
 DROP VIEW SCI_C_FOLDER;
 DROP VIEW SCI_V_FOLDER;
 CREATE VIEW SCI_C_FOLDER AS
@@ -518,22 +505,6 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
   FROM INTERVALL;
-DROP VIEW SCI_INTERVAL_DISPATCHER;
-CREATE VIEW SCI_INTERVAL_DISPATCHER AS
-SELECT 
-    ID 
-    , INT_ID                         AS INT_ID
-    , SEQ_NO                         AS SEQ_NO
-    , NAME                           AS NAME
-    , SELECT_INT_ID                  AS SELECT_INT_ID
-    , FILTER_INT_ID                  AS FILTER_INT_ID
-    , DECODE (IS_ENABLED, 1, 'TRUE', 0, 'FALSE') AS IS_ENABLED
-    , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-  FROM INTERVAL_DISPATCHER;
 DROP VIEW SCI_INTERVAL_HIERARCHY;
 CREATE VIEW SCI_INTERVAL_HIERARCHY AS
 SELECT 
@@ -621,33 +592,6 @@ SELECT
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
     , INHERIT_PRIVS                  AS INHERIT_PRIVS
   FROM NAMED_RESOURCE;
-DROP VIEW SCI_NICE_PROFILE;
-CREATE VIEW SCI_NICE_PROFILE AS
-SELECT 
-    ID 
-    , NAME                           AS NAME
-    , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
-    , ACTIVE_TS                      AS ACTIVE_TS
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-  FROM NICE_PROFILE;
-DROP VIEW SCI_NICE_PROFILE_ENTRY;
-CREATE VIEW SCI_NICE_PROFILE_ENTRY AS
-SELECT 
-    ID 
-    , NP_ID                          AS NP_ID
-    , PREFERENCE                     AS PREFERENCE
-    , FOLDER_ID                      AS FOLDER_ID
-    , DECODE (IS_SUSPENDED, 0, 'NOSUSPEND', 1, 'SUSPEND', 2, 'ADMINSUSPEND') AS IS_SUSPENDED
-    , RENICE                         AS RENICE
-    , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-  FROM NICE_PROFILE_ENTRY;
 DROP VIEW SCI_MEMBER;
 CREATE VIEW SCI_MEMBER AS
 SELECT 
@@ -1457,30 +1401,6 @@ SELECT
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
     , ((NVL(FINAL_TS, TIMESTAMPDIFF(2, CURRENT TIMESTAMP - CURRENT TIMEZONE - TIMESTAMP('1970-01-01-00.00.00')) * 1000) - SUBMIT_TS) / 1000) - DEPENDENCY_WAIT_TIME AS PROCESS_TIME
   FROM SUBMITTED_ENTITY;
-DROP VIEW SCI_SUBMITTED_ENTITY_STATS;
-CREATE VIEW SCI_SUBMITTED_ENTITY_STATS AS
-SELECT 
-    ID 
-    , SME_ID                         AS SME_ID
-    , RERUN_SEQ                      AS RERUN_SEQ
-    , SCOPE_ID                       AS SCOPE_ID
-    , JOB_ESD_ID                     AS JOB_ESD_ID
-    , EXIT_CODE                      AS EXIT_CODE
-    , COMMANDLINE                    AS COMMANDLINE
-    , WORKDIR                        AS WORKDIR
-    , LOGFILE                        AS LOGFILE
-    , ERRLOGFILE                     AS ERRLOGFILE
-    , EXTPID                         AS EXTPID
-    , timestamp('1970-01-01-00.00.00') + int(mod(SYNC_TS, 1125899906842624)/1000) seconds AS SYNC_TS
-    , timestamp('1970-01-01-00.00.00') + int(mod(RESOURCE_TS, 1125899906842624)/1000) seconds AS RESOURCE_TS
-    , timestamp('1970-01-01-00.00.00') + int(mod(RUNNABLE_TS, 1125899906842624)/1000) seconds AS RUNNABLE_TS
-    , timestamp('1970-01-01-00.00.00') + int(mod(START_TS, 1125899906842624)/1000) seconds AS START_TS
-    , timestamp('1970-01-01-00.00.00') + int(mod(FINISH_TS, 1125899906842624)/1000) seconds AS FINISH_TS
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-  FROM SUBMITTED_ENTITY_STATS;
 DROP VIEW SCI_C_TEMPLATE_VARIABLE;
 DROP VIEW SCI_V_TEMPLATE_VARIABLE;
 CREATE VIEW SCI_C_TEMPLATE_VARIABLE AS
@@ -1577,33 +1497,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM TRIGGER_DEFINITION;
-DROP VIEW SCI_C_TRIGGER_PARAMETER;
-DROP VIEW SCI_V_TRIGGER_PARAMETER;
-CREATE VIEW SCI_C_TRIGGER_PARAMETER AS
-SELECT 
-    ID 
-    , NAME                           AS NAME
-    , EXPRESSION                     AS EXPRESSION
-    , TRIGGER_ID                     AS TRIGGER_ID
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-  FROM TRIGGER_PARAMETER
- WHERE VALID_TO = 9223372036854775807;
-CREATE VIEW SCI_V_TRIGGER_PARAMETER AS
-SELECT 
-    ID 
-    , NAME                           AS NAME
-    , EXPRESSION                     AS EXPRESSION
-    , TRIGGER_ID                     AS TRIGGER_ID
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-    , VALID_FROM
-    , VALID_TO
-  FROM TRIGGER_PARAMETER;
 DROP VIEW SCI_TRIGGER_QUEUE;
 CREATE VIEW SCI_TRIGGER_QUEUE AS
 SELECT 
@@ -1661,45 +1554,6 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
   FROM USERS;
-DROP VIEW SCI_USER_EQUIV;
-CREATE VIEW SCI_USER_EQUIV AS
-SELECT 
-    ID 
-    , U_ID                           AS U_ID
-    , DECODE (ALT_U_TYPE, 0, 'USER', 1, 'SERVER') AS ALT_U_TYPE
-    , ALT_U_ID                       AS ALT_U_ID
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-  FROM USER_EQUIV;
-DROP VIEW SCI_C_VERSIONED_EXTENTS;
-DROP VIEW SCI_V_VERSIONED_EXTENTS;
-CREATE VIEW SCI_C_VERSIONED_EXTENTS AS
-SELECT 
-    ID 
-    , O_ID                           AS O_ID
-    , SEQUENCE                       AS SEQUENCE
-    , EXTENT                         AS EXTENT
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-  FROM VERSIONED_EXTENTS
- WHERE VALID_TO = 9223372036854775807;
-CREATE VIEW SCI_V_VERSIONED_EXTENTS AS
-SELECT 
-    ID 
-    , O_ID                           AS O_ID
-    , SEQUENCE                       AS SEQUENCE
-    , EXTENT                         AS EXTENT
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CREATE_TS, 1125899906842624)/1000) seconds AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , timestamp('1970-01-01-00.00.00') + int(mod(CHANGE_TS, 1125899906842624)/1000) seconds AS CHANGE_TS
-    , VALID_FROM
-    , VALID_TO
-  FROM VERSIONED_EXTENTS;
 DROP VIEW SCI_C_WATCH_TYPE;
 DROP VIEW SCI_V_WATCH_TYPE;
 CREATE VIEW SCI_C_WATCH_TYPE AS
@@ -1773,3 +1627,4 @@ UPDATE RESOURCE_ALLOCATION
  WHERE IS_STICKY = 1
    AND SME_ID < 0;
 ALTER TABLE SCOPE ALTER PASSWD SET DATA TYPE VARCHAR(64);
+commit;
