@@ -22,7 +22,7 @@ INSERT INTO `VERSIONCOUNTER` VALUES (1);
 /*--------------------------------------------------------------------------------*/
 
 INSERT INTO `GROUPS` (`ID`,  `NAME`, `DELETE_VERSION`, `CREATOR_U_ID`, `CREATE_TS`, `CHANGER_U_ID`, `CHANGE_TS`)
-	VALUES       ( 80, 'PUBLIC',               0,              0,           0,              0,           0);
+	VALUES       (80,  'PUBLIC',               0,              0,           0,              0,           0);
 
 /*-- IMPORTANT!!!*/
 /*--	If this ID is changed, it also has to be changed in SDMSObject.java*/
@@ -40,7 +40,7 @@ INSERT INTO `USERS` (`ID`,       `NAME`,                              `PASSWD`,
 	VALUES      (  1,      'NOBODY', 'xxxxxxxx xxxxxxxx xxxxxxxx xxxxxxxx',  null,        0,            0,             80,                 0,                0,              0,           0,              0,           0);
                                                                                       
 INSERT INTO `USERS` (`ID`,       `NAME`,                              `PASSWD`, `SALT`, `METHOD`, `IS_ENABLED`, `DEFAULT_G_ID`, `CONNECTION_TYPE`, `DELETE_VERSION`, `CREATOR_U_ID`, `CREATE_TS`, `CHANGER_U_ID`, `CHANGE_TS`)
-	VALUES      (  2,    'INTERNAL', 'xxxxxxxx xxxxxxxx xxxxxxxx xxxxxxxx',  null,        0,          0,               81,                 0,                0,              0,           0,              0,           0);
+	VALUES      (  2,    'INTERNAL', 'xxxxxxxx xxxxxxxx xxxxxxxx xxxxxxxx',  null,        0,            0,             81,                 0,                0,              0,           0,              0,           0);
 
 
 /*--------------------------------------------------------------------------------*/
@@ -51,10 +51,10 @@ INSERT INTO `USERS` (`ID`,       `NAME`,                              `PASSWD`,
 /*-- IMPORTANT!!!*/
 /*--	If this ID is changed, it also has to be changed in SDMSObject.java*/
 INSERT INTO `SCHEDULING_HIERARCHY` (
-	`ID`, `SE_PARENT_ID`, `SE_CHILD_ID`, `ALIAS_NAME`, `IS_STATIC`, `IS_DISABLED`, `PRIORITY`, `SUSPEND`, `MERGE_MODE`, `ESTP_ID`,
-	`CREATOR_U_ID`, `CREATE_TS`, `CHANGER_U_ID`, `CHANGE_TS`, `VALID_FROM`,          `VALID_TO`)
+	`ID`, `SE_PARENT_ID`, `SE_CHILD_ID`, `ALIAS_NAME`, `IS_STATIC`, `IS_DISABLED`, `PRIORITY`, `SUSPEND`, `MERGE_MODE`, `ESTP_ID`, `ENABLE_MODE`,
+	`CREATOR_U_ID`, `CREATE_TS`, `CHANGER_U_ID`, `CHANGE_TS`, `VALID_FROM`,         `VALID_TO`)
 VALUES (
-	 30,           NULL,          NULL,         NULL,           0,             0,          0,         1,            3,      NULL, 
+	 30,           NULL,          NULL,         NULL,           0,             0,          0,         1,            3,      NULL,             1,
 	            0,           0,              0,           0,            0, 9223372036854775807);
 
 /*--------------------------------------------------------------------------------*/
@@ -63,7 +63,7 @@ VALUES (
 
 /*-- Create SYSTEM folder owned by ADMIN without parent*/
 INSERT INTO `FOLDER` (`ID`,  `NAME`,     `OWNER_ID`, `ENV_ID`, `PARENT_ID`, `VALID_FROM`,          `VALID_TO`, `CREATOR_U_ID`, `CREATE_TS`, `CHANGER_U_ID`, `CHANGE_TS`, `INHERIT_PRIVS`)
-	VALUES       ( 40, 'SYSTEM',            81,     NULL,        NULL,            0, 9223372036854775807,              0,           0,              0,           0,               0);
+	VALUES       ( 40, 'SYSTEM',            81,      NULL,       NULL,            0, 9223372036854775807,              0,           0,              0,           0,               0);
 
 /*--------------------------------------------------------------------------------*/
 /*--	Table "SCOPE"*/
