@@ -337,18 +337,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM EXIT_STATE_TRANS_PROFILE;
-CREATE OR REPLACE VIEW SCI_EXTENTS AS
-SELECT 
-    ID 
-    , O_ID                           AS O_ID
-    , SME_ID                         AS SME_ID
-    , SEQUENCE                       AS SEQUENCE
-    , EXTENT                         AS EXTENT
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
-  FROM EXTENTS;
 CREATE OR REPLACE VIEW SCI_C_FOLDER AS
 SELECT 
     ID 
@@ -481,21 +469,6 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
   FROM INTERVALL;
-CREATE OR REPLACE VIEW SCI_INTERVAL_DISPATCHER AS
-SELECT 
-    ID 
-    , INT_ID                         AS INT_ID
-    , SEQ_NO                         AS SEQ_NO
-    , NAME                           AS NAME
-    , SELECT_INT_ID                  AS SELECT_INT_ID
-    , FILTER_INT_ID                  AS FILTER_INT_ID
-    , DECODE (IS_ENABLED, 1, 'TRUE', 0, 'FALSE') AS IS_ENABLED
-    , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
-  FROM INTERVAL_DISPATCHER;
 CREATE OR REPLACE VIEW SCI_INTERVAL_HIERARCHY AS
 SELECT 
     ID 
@@ -612,6 +585,9 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
   FROM MEMBER;
+ALTER TABLE OBJECT_COMMENT ADD (
+    TAG VARCHAR2 (64 CHAR)
+);
 CREATE OR REPLACE VIEW SCI_C_OBJECT_COMMENT AS
 SELECT 
     ID 
@@ -619,6 +595,7 @@ SELECT
     , DECODE (OBJECT_TYPE, 9, 'JOB_DEFINITION', 2, 'EXIT_STATE_DEFINITION', 3, 'EXIT_STATE_PROFILE', 4, 'EXIT_STATE_MAPPING', 5, 'EXIT_STATE_TRANSLATION', 6, 'FOLDER', 15, 'SCOPE', 10, 'NAMED_RESOURCE', 31, 'NICE_PROFILE', 11, 'RESOURCE', 1, 'ENVIRONMENT', 7, 'FOOTPRINT', 13, 'RESOURCE_STATE_DEFINITION', 14, 'RESOURCE_STATE_PROFILE', 12, 'RESOURCE_STATE_MAPPING', 8, 'USER', 16, 'TRIGGER', 17, 'JOB', 18, 'EVENT', 19, 'INTERVAL', 20, 'SCHEDULE', 22, 'SCHEDULED_EVENT', 21, 'GROUP', 23, 'PARAMETER', 24, 'POOL', 25, 'DISTRIBUTION', 29, 'WATCH_TYPE', 30, 'OBJECT_MONITOR') AS OBJECT_TYPE
     , DECODE (INFO_TYPE, 0, 'TEXT', 1, 'URL') AS INFO_TYPE
     , SEQUENCE_NUMBER                AS SEQUENCE_NUMBER
+    , TAG                            AS TAG
     , DESCRIPTION                    AS DESCRIPTION
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
@@ -633,6 +610,7 @@ SELECT
     , DECODE (OBJECT_TYPE, 9, 'JOB_DEFINITION', 2, 'EXIT_STATE_DEFINITION', 3, 'EXIT_STATE_PROFILE', 4, 'EXIT_STATE_MAPPING', 5, 'EXIT_STATE_TRANSLATION', 6, 'FOLDER', 15, 'SCOPE', 10, 'NAMED_RESOURCE', 31, 'NICE_PROFILE', 11, 'RESOURCE', 1, 'ENVIRONMENT', 7, 'FOOTPRINT', 13, 'RESOURCE_STATE_DEFINITION', 14, 'RESOURCE_STATE_PROFILE', 12, 'RESOURCE_STATE_MAPPING', 8, 'USER', 16, 'TRIGGER', 17, 'JOB', 18, 'EVENT', 19, 'INTERVAL', 20, 'SCHEDULE', 22, 'SCHEDULED_EVENT', 21, 'GROUP', 23, 'PARAMETER', 24, 'POOL', 25, 'DISTRIBUTION', 29, 'WATCH_TYPE', 30, 'OBJECT_MONITOR') AS OBJECT_TYPE
     , DECODE (INFO_TYPE, 0, 'TEXT', 1, 'URL') AS INFO_TYPE
     , SEQUENCE_NUMBER                AS SEQUENCE_NUMBER
+    , TAG                            AS TAG
     , DESCRIPTION                    AS DESCRIPTION
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
@@ -702,6 +680,9 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
   FROM OBJECT_MONITOR_PARAMETER;
+ALTER TABLE PARAMETER_DEFINITION ADD (
+    EXPORT_NAME VARCHAR2 (64 CHAR)
+);
 CREATE OR REPLACE VIEW SCI_C_PARAMETER_DEFINITION AS
 SELECT 
     ID 
@@ -712,6 +693,7 @@ SELECT
     , DEFAULTVALUE                   AS DEFAULTVALUE
     , DECODE (IS_LOCAL, 1, 'TRUE', 0, 'FALSE') AS IS_LOCAL
     , LINK_PD_ID                     AS LINK_PD_ID
+    , EXPORT_NAME                    AS EXPORT_NAME
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
@@ -728,6 +710,7 @@ SELECT
     , DEFAULTVALUE                   AS DEFAULTVALUE
     , DECODE (IS_LOCAL, 1, 'TRUE', 0, 'FALSE') AS IS_LOCAL
     , LINK_PD_ID                     AS LINK_PD_ID
+    , EXPORT_NAME                    AS EXPORT_NAME
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
@@ -853,10 +836,6 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
   FROM RESSOURCE;
-ALTER TABLE RESOURCE_ALLOCATION ADD (
-    STICKY_NAME VARCHAR2 (64 CHAR),
-    STICKY_PARENT NUMBER (38)
-);
 CREATE OR REPLACE VIEW SCI_RESOURCE_ALLOCATION AS
 SELECT 
     ID 
@@ -901,10 +880,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM RESOURCE_REQ_STATES;
-ALTER TABLE RESOURCE_REQUIREMENT ADD (
-    STICKY_NAME VARCHAR2 (64 CHAR),
-    STICKY_PARENT NUMBER (38)
-);
 CREATE OR REPLACE VIEW SCI_C_RESOURCE_REQUIREMENT AS
 SELECT 
     ID 
@@ -1204,6 +1179,9 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM SCHEDULING_ENTITY;
+ALTER TABLE SCHEDULING_HIERARCHY ADD (
+    IS_DISABLED NUMBER (1) DEFAULT 0 NOT NULL
+);
 CREATE OR REPLACE VIEW SCI_C_SCHEDULING_HIERARCHY AS
 SELECT 
     ID 
@@ -1211,6 +1189,7 @@ SELECT
     , SE_CHILD_ID                    AS SE_CHILD_ID
     , ALIAS_NAME                     AS ALIAS_NAME
     , DECODE (IS_STATIC, 1, 'STATIC', 0, 'DYNAMIC') AS IS_STATIC
+    , DECODE (IS_DISABLED, 0, 'ENABLED', 1, 'DISABLED') AS IS_DISABLED
     , PRIORITY                       AS PRIORITY
     , DECODE (SUSPEND, 1, 'CHILDSUSPEND', 2, 'NOSUSPEND', 3, 'SUSPEND') AS SUSPEND
     , RESUME_AT                      AS RESUME_AT
@@ -1231,6 +1210,7 @@ SELECT
     , SE_CHILD_ID                    AS SE_CHILD_ID
     , ALIAS_NAME                     AS ALIAS_NAME
     , DECODE (IS_STATIC, 1, 'STATIC', 0, 'DYNAMIC') AS IS_STATIC
+    , DECODE (IS_DISABLED, 0, 'ENABLED', 1, 'DISABLED') AS IS_DISABLED
     , PRIORITY                       AS PRIORITY
     , DECODE (SUSPEND, 1, 'CHILDSUSPEND', 2, 'NOSUSPEND', 3, 'SUSPEND') AS SUSPEND
     , RESUME_AT                      AS RESUME_AT
@@ -1245,10 +1225,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM SCHEDULING_HIERARCHY;
-ALTER TABLE SCOPE ADD (
-    SALT VARCHAR2 (64 CHAR),
-    METHOD NUMBER (38) DEFAULT 0 NOT NULL
-);
 CREATE OR REPLACE VIEW SCI_SCOPE AS
 SELECT 
     ID 
@@ -1306,6 +1282,14 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
   FROM SME_COUNTER;
+ALTER TABLE SUBMITTED_ENTITY ADD (
+    IS_DISABLED NUMBER (1) DEFAULT 0 NOT NULL,
+    OLD_STATE NUMBER (38)
+);
+ALTER TABLE ARC_SUBMITTED_ENTITY ADD (
+    IS_DISABLED NUMBER (1),
+    OLD_STATE NUMBER (38)
+);
 CREATE OR REPLACE VIEW SCI_SUBMITTED_ENTITY AS
 SELECT 
     ID 
@@ -1319,6 +1303,8 @@ SELECT
     , PARENT_ID                      AS PARENT_ID
     , SCOPE_ID                       AS SCOPE_ID
     , DECODE (IS_STATIC, 1, 'TRUE', 0, 'FALSE') AS IS_STATIC
+    , DECODE (IS_DISABLED, 1, 'TRUE', 0, 'FALSE') AS IS_DISABLED
+    , OLD_STATE                      AS OLD_STATE
     , DECODE (MERGE_MODE, 1, 'MERGE_LOCAL', 2, 'MERGE_GLOBAL', 3, 'NOMERGE', 4, 'FAILURE') AS MERGE_MODE
     , DECODE (STATE, 0, 'SUBMITTED', 1, 'DEPENDENCY_WAIT', 2, 'SYNCHRONIZE_WAIT', 3, 'RESOURCE_WAIT', 4, 'RUNNABLE', 5, 'STARTING', 6, 'STARTED', 7, 'RUNNING', 8, 'TO_KILL', 9, 'KILLED', 10, 'CANCELLED', 11, 'FINISHED', 12, 'FINAL', 13, 'BROKEN_ACTIVE', 14, 'BROKEN_FINISHED', 15, 'ERROR', 16, 'UNREACHABLE') AS STATE
     , JOB_ESD_ID                     AS JOB_ESD_ID
@@ -1351,7 +1337,9 @@ SELECT
     , DECODE (IS_SUSPENDED, 2, 'ADMINSUSPEND', 1, 'SUSPEND', 0, 'NOSUSPEND') AS IS_SUSPENDED
     , DECODE (IS_SUSPENDED_LOCAL, 1, 'TRUE', 0, 'FALSE') AS IS_SUSPENDED_LOCAL
     , PRIORITY                       AS PRIORITY
+    , RAW_PRIORITY                   AS RAW_PRIORITY
     , NICE                           AS NICE
+    , NP_NICE                        AS NP_NICE
     , MIN_PRIORITY                   AS MIN_PRIORITY
     , AGING_AMOUNT                   AS AGING_AMOUNT
     , PARENT_SUSPENDED               AS PARENT_SUSPENDED
@@ -1366,35 +1354,22 @@ SELECT
     , pkg_time.gmt2local(START_TS) AS START_TS
     , pkg_time.gmt2local(FINSH_TS) AS FINSH_TS
     , pkg_time.gmt2local(FINAL_TS) AS FINAL_TS
+    , IDLE_TIME                      AS IDLE_TIME
+    , DEPENDENCY_WAIT_TIME           AS DEPENDENCY_WAIT_TIME
+    , SUSPEND_TIME                   AS SUSPEND_TIME
+    , SYNC_TIME                      AS SYNC_TIME
+    , RESOURCE_TIME                  AS RESOURCE_TIME
+    , JOBSERVER_TIME                 AS JOBSERVER_TIME
+    , RESTARTABLE_TIME               AS RESTARTABLE_TIME
+    , CHILD_WAIT_TIME                AS CHILD_WAIT_TIME
+    , OP_SUSRES_TS                   AS OP_SUSRES_TS
+    , NPE_ID                         AS NPE_ID
     , CREATOR_U_ID                   AS CREATOR_U_ID
     , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
     , ((NVL(FINAL_TS, (CAST(SYS_EXTRACT_UTC(SYSTIMESTAMP) AS DATE) - TO_DATE('19700101', 'YYYYDDSS')) * 24 * 60 * 60 * 1000) - SUBMIT_TS) / 1000) - DEPENDENCY_WAIT_TIME AS PROCESS_TIME
   FROM SUBMITTED_ENTITY;
-CREATE OR REPLACE VIEW SCI_SUBMITTED_ENTITY_STATS AS
-SELECT 
-    ID 
-    , SME_ID                         AS SME_ID
-    , RERUN_SEQ                      AS RERUN_SEQ
-    , SCOPE_ID                       AS SCOPE_ID
-    , JOB_ESD_ID                     AS JOB_ESD_ID
-    , EXIT_CODE                      AS EXIT_CODE
-    , COMMANDLINE                    AS COMMANDLINE
-    , WORKDIR                        AS WORKDIR
-    , LOGFILE                        AS LOGFILE
-    , ERRLOGFILE                     AS ERRLOGFILE
-    , EXTPID                         AS EXTPID
-    , pkg_time.gmt2local(SYNC_TS) AS SYNC_TS
-    , pkg_time.gmt2local(RESOURCE_TS) AS RESOURCE_TS
-    , pkg_time.gmt2local(RUNNABLE_TS) AS RUNNABLE_TS
-    , pkg_time.gmt2local(START_TS) AS START_TS
-    , pkg_time.gmt2local(FINISH_TS) AS FINISH_TS
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
-  FROM SUBMITTED_ENTITY_STATS;
 CREATE OR REPLACE VIEW SCI_C_TEMPLATE_VARIABLE AS
 SELECT 
     ID 
@@ -1420,6 +1395,10 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM TEMPLATE_VARIABLE;
+ALTER TABLE TRIGGER_DEFINITION ADD (
+    IS_INVERSE NUMBER (1) DEFAULT 0 NOT NULL,
+    LIMIT_STATE NUMBER (38)
+);
 CREATE OR REPLACE VIEW SCI_C_TRIGGER_DEFINITION AS
 SELECT 
     ID 
@@ -1430,6 +1409,7 @@ SELECT
     , MAIN_SE_ID                     AS MAIN_SE_ID
     , PARENT_SE_ID                   AS PARENT_SE_ID
     , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
+    , DECODE (IS_INVERSE, 1, 'TRUE', 0, 'FALSE') AS IS_INVERSE
     , DECODE (ACTION, 0, 'SUBMIT', 1, 'RERUN') AS ACTION
     , DECODE (TYPE, 0, 'IMMEDIATE_LOCAL', 2, 'BEFORE_FINAL', 3, 'AFTER_FINAL', 1, 'IMMEDIATE_MERGE', 4, 'FINISH_CHILD', 5, 'UNTIL_FINISHED', 6, 'UNTIL_FINAL', 7, 'WARNING') AS TYPE
     , DECODE (IS_MASTER, 1, 'MASTER', 0, 'NOMASTER') AS IS_MASTER
@@ -1442,6 +1422,7 @@ SELECT
     , RESUME_IN                      AS RESUME_IN
     , DECODE (RESUME_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS RESUME_BASE
     , DECODE (IS_WARN_ON_LIMIT, 1, 'TRUE', 0, 'FALSE') AS IS_WARN_ON_LIMIT
+    , LIMIT_STATE                    AS LIMIT_STATE
     , MAX_RETRY                      AS MAX_RETRY
     , SUBMIT_OWNER_ID                AS SUBMIT_OWNER_ID
     , CONDITION                      AS CONDITION
@@ -1463,6 +1444,7 @@ SELECT
     , MAIN_SE_ID                     AS MAIN_SE_ID
     , PARENT_SE_ID                   AS PARENT_SE_ID
     , DECODE (IS_ACTIVE, 1, 'TRUE', 0, 'FALSE') AS IS_ACTIVE
+    , DECODE (IS_INVERSE, 1, 'TRUE', 0, 'FALSE') AS IS_INVERSE
     , DECODE (ACTION, 0, 'SUBMIT', 1, 'RERUN') AS ACTION
     , DECODE (TYPE, 0, 'IMMEDIATE_LOCAL', 2, 'BEFORE_FINAL', 3, 'AFTER_FINAL', 1, 'IMMEDIATE_MERGE', 4, 'FINISH_CHILD', 5, 'UNTIL_FINISHED', 6, 'UNTIL_FINAL', 7, 'WARNING') AS TYPE
     , DECODE (IS_MASTER, 1, 'MASTER', 0, 'NOMASTER') AS IS_MASTER
@@ -1475,6 +1457,7 @@ SELECT
     , RESUME_IN                      AS RESUME_IN
     , DECODE (RESUME_BASE, 0, 'MINUTE', 1, 'HOUR', 2, 'DAY', 3, 'WEEK', 4, 'MONTH', 5, 'YEAR') AS RESUME_BASE
     , DECODE (IS_WARN_ON_LIMIT, 1, 'TRUE', 0, 'FALSE') AS IS_WARN_ON_LIMIT
+    , LIMIT_STATE                    AS LIMIT_STATE
     , MAX_RETRY                      AS MAX_RETRY
     , SUBMIT_OWNER_ID                AS SUBMIT_OWNER_ID
     , CONDITION                      AS CONDITION
@@ -1487,31 +1470,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM TRIGGER_DEFINITION;
-CREATE OR REPLACE VIEW SCI_C_TRIGGER_PARAMETER AS
-SELECT 
-    ID 
-    , NAME                           AS NAME
-    , EXPRESSION                     AS EXPRESSION
-    , TRIGGER_ID                     AS TRIGGER_ID
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
-  FROM TRIGGER_PARAMETER
- WHERE VALID_TO = 9223372036854775807;
-CREATE OR REPLACE VIEW SCI_V_TRIGGER_PARAMETER AS
-SELECT 
-    ID 
-    , NAME                           AS NAME
-    , EXPRESSION                     AS EXPRESSION
-    , TRIGGER_ID                     AS TRIGGER_ID
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
-    , VALID_FROM
-    , VALID_TO
-  FROM TRIGGER_PARAMETER;
 CREATE OR REPLACE VIEW SCI_TRIGGER_QUEUE AS
 SELECT 
     ID 
@@ -1550,10 +1508,6 @@ SELECT
     , VALID_FROM
     , VALID_TO
   FROM TRIGGER_STATE;
-ALTER TABLE USERS ADD (
-    SALT VARCHAR2 (64 CHAR),
-    METHOD NUMBER (38) DEFAULT 0 NOT NULL
-);
 CREATE OR REPLACE VIEW SCI_USERS AS
 SELECT 
     ID 
@@ -1566,42 +1520,6 @@ SELECT
     , CHANGER_U_ID                   AS CHANGER_U_ID
     , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
   FROM USERS;
-CREATE OR REPLACE VIEW SCI_USER_EQUIV AS
-SELECT 
-    ID 
-    , U_ID                           AS U_ID
-    , DECODE (ALT_U_TYPE, 0, 'USER', 1, 'SERVER') AS ALT_U_TYPE
-    , ALT_U_ID                       AS ALT_U_ID
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
-  FROM USER_EQUIV;
-CREATE OR REPLACE VIEW SCI_C_VERSIONED_EXTENTS AS
-SELECT 
-    ID 
-    , O_ID                           AS O_ID
-    , SEQUENCE                       AS SEQUENCE
-    , EXTENT                         AS EXTENT
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
-  FROM VERSIONED_EXTENTS
- WHERE VALID_TO = 9223372036854775807;
-CREATE OR REPLACE VIEW SCI_V_VERSIONED_EXTENTS AS
-SELECT 
-    ID 
-    , O_ID                           AS O_ID
-    , SEQUENCE                       AS SEQUENCE
-    , EXTENT                         AS EXTENT
-    , CREATOR_U_ID                   AS CREATOR_U_ID
-    , pkg_time.gmt2local(CREATE_TS) AS CREATE_TS
-    , CHANGER_U_ID                   AS CHANGER_U_ID
-    , pkg_time.gmt2local(CHANGE_TS) AS CHANGE_TS
-    , VALID_FROM
-    , VALID_TO
-  FROM VERSIONED_EXTENTS;
 CREATE OR REPLACE VIEW SCI_C_WATCH_TYPE AS
 SELECT 
     ID 
@@ -1650,24 +1568,3 @@ SELECT
     , pkg_time.gmt2local(WRITE_TIME) AS WRITE_TIME
     , pkg_time.gmt2local(LAST_WRITE) AS LAST_WRITE
   FROM RESOURCE_TRACE;
-CREATE TABLE SME2LOAD (ID NUMBER NOT NULL);
-CREATE INDEX SME2LOAD_IDX ON SME2LOAD (ID);
-CREATE INDEX SME_IDX ON SUBMITTED_ENTITY (MASTER_ID, ID, STATE, FINAL_TS);
-CREATE INDEX KILL_JOB_IDX ON KILL_JOB (SME_ID);
-CREATE INDEX AUDIT_TRAIL_IDX ON AUDIT_TRAIL (OBJECT_ID);
-CREATE INDEX ENTITY_VARIABLE_IDX ON ENTITY_VARIABLE (SME_ID);
-CREATE INDEX DEPENDENCY_INSTANCE_IDX ON DEPENDENCY_INSTANCE (DEPENDENT_ID);
-CREATE INDEX HIERARCHY_INSTANCE_IDX ON HIERARCHY_INSTANCE (CHILD_ID);
-UPDATE RESOURCE_ALLOCATION
-   SET STICKY_PARENT = (
-       SELECT MASTER_ID
-         FROM SUBMITTED_ENTITY
-        WHERE ID = SME_ID
-       )
- WHERE IS_STICKY = 1
-   AND SME_ID > 0;
-UPDATE RESOURCE_ALLOCATION
-   SET STICKY_PARENT = -SME_ID
- WHERE IS_STICKY = 1
-   AND SME_ID < 0;
-ALTER TABLE SCOPE MODIFY (PASSWD VARCHAR2(64 CHAR));
